@@ -41,7 +41,7 @@ pub trait QueryBuilder: QuotedBuilder {
                 if !first {
                     write!(sql, ", ").unwrap()
                 }
-                self.prepare_value(col, sql, collector);
+                self.prepare_simple_expr(col, sql, collector);
                 false
             });
             write!(sql, ")").unwrap();
@@ -101,6 +101,16 @@ pub trait QueryBuilder: QuotedBuilder {
 
         self.prepare_condition(&select.having, "HAVING", sql, collector);
 
+        if !select.unions.is_empty() {
+            select.unions.iter().for_each(|(union_type, query)| {
+                match union_type {
+                    UnionType::Distinct => write!(sql, " UNION ").unwrap(),
+                    UnionType::All => write!(sql, " UNION ALL ").unwrap(),
+                }
+                self.prepare_select_statement(query, sql, collector);
+            });
+        }
+
         if !select.orders.is_empty() {
             write!(sql, " ORDER BY ").unwrap();
             select.orders.iter().fold(true, |first, expr| {
@@ -205,6 +215,8 @@ pub trait QueryBuilder: QuotedBuilder {
             write!(sql, " LIMIT ").unwrap();
             self.prepare_value(limit, sql, collector);
         }
+
+        self.prepare_returning(&delete.returning, sql, collector);
     }
 
     /// Translate [`SimpleExpr`] into SQL statement.
@@ -474,6 +486,7 @@ pub trait QueryBuilder: QuotedBuilder {
                 BinOper::Sub => "-",
                 BinOper::Mul => "*",
                 BinOper::Div => "/",
+                BinOper::As => "AS",
                 _ => unimplemented!(),
             }
         )
@@ -543,6 +556,7 @@ pub trait QueryBuilder: QuotedBuilder {
                     Function::Count => "COUNT",
                     Function::IfNull => self.if_null_function(),
                     Function::CharLength => self.char_length_function(),
+                    Function::Cast => "CAST",
                     Function::Custom(_) => "",
                     #[cfg(feature = "backend-postgres")]
                     Function::PgFunction(_) => unimplemented!(),
