@@ -202,6 +202,7 @@ impl Expr {
     ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE IFNULL(`size_w`, 0) > 2"#
     /// );
     /// ```
+    #[allow(clippy::self_named_constructors)]
     pub fn expr(expr: SimpleExpr) -> Self {
         Self::new_with_left(expr)
     }
@@ -1435,7 +1436,7 @@ impl Expr {
         self.into()
     }
 
-    fn bin_oper(mut self, o: BinOper, e: SimpleExpr) -> SimpleExpr {
+    pub(crate) fn bin_oper(mut self, o: BinOper, e: SimpleExpr) -> SimpleExpr {
         self.bopr = Some(o);
         self.right = Some(e);
         self.into()
