@@ -2,15 +2,15 @@
 
 pub use std::fmt::Write as FmtWrite;
 
-#[cfg(feature="with-json")]
+#[cfg(feature = "with-json")]
 pub use serde_json::json;
 
 use crate::Iden;
 
 /// Representation of a database table named `Character`.
-/// 
+///
 /// A `Enum` implemented [`Iden`] used in rustdoc and test to demonstrate the library usage.
-/// 
+///
 /// [`Iden`]: crate::types::Iden
 #[derive(Debug)]
 pub enum Character {
@@ -28,22 +28,27 @@ pub type Char = Character;
 
 impl Iden for Character {
     fn unquoted(&self, s: &mut dyn FmtWrite) {
-        write!(s, "{}", match self {
-            Self::Table => "character",
-            Self::Id => "id",
-            Self::Character => "character",
-            Self::FontSize => "font_size",
-            Self::SizeW => "size_w",
-            Self::SizeH => "size_h",
-            Self::FontId => "font_id",
-        }).unwrap();
+        write!(
+            s,
+            "{}",
+            match self {
+                Self::Table => "character",
+                Self::Id => "id",
+                Self::Character => "character",
+                Self::FontSize => "font_size",
+                Self::SizeW => "size_w",
+                Self::SizeH => "size_h",
+                Self::FontId => "font_id",
+            }
+        )
+        .unwrap();
     }
 }
 
 /// Representation of a database table named `Font`.
-/// 
+///
 /// A `Enum` implemented [`Iden`] used in rustdoc and test to demonstrate the library usage.
-/// 
+///
 /// [`Iden`]: crate::types::Iden
 #[derive(Debug)]
 pub enum Font {
@@ -56,20 +61,25 @@ pub enum Font {
 
 impl Iden for Font {
     fn unquoted(&self, s: &mut dyn FmtWrite) {
-        write!(s, "{}", match self {
-            Self::Table => "font",
-            Self::Id => "id",
-            Self::Name => "name",
-            Self::Variant => "variant",
-            Self::Language => "language",
-        }).unwrap();
+        write!(
+            s,
+            "{}",
+            match self {
+                Self::Table => "font",
+                Self::Id => "id",
+                Self::Name => "name",
+                Self::Variant => "variant",
+                Self::Language => "language",
+            }
+        )
+        .unwrap();
     }
 }
 
 /// Representation of a database table named `Glyph`.
-/// 
+///
 /// A `Enum` implemented [`Iden`] used in rustdoc and test to demonstrate the library usage.
-/// 
+///
 /// [`Iden`]: crate::types::Iden
 #[derive(Debug)]
 pub enum Glyph {
@@ -81,11 +91,16 @@ pub enum Glyph {
 
 impl Iden for Glyph {
     fn unquoted(&self, s: &mut dyn FmtWrite) {
-        write!(s, "{}", match self {
-            Self::Table => "glyph",
-            Self::Id => "id",
-            Self::Image => "image",
-            Self::Aspect => "aspect",
-        }).unwrap();
+        write!(
+            s,
+            "{}",
+            match self {
+                Self::Table => "glyph",
+                Self::Id => "id",
+                Self::Image => "image",
+                Self::Aspect => "aspect",
+            }
+        )
+        .unwrap();
     }
-}
\ No newline at end of file
+}
