@@ -678,22 +678,6 @@ fn select_43() {
     assert_eq!(statement, r#"SELECT "id" FROM "glyph""#);
 }
 
-#[test]
-#[allow(clippy::approx_constant)]
-#[cfg(feature = "with-json")]
-fn insert_1() {
-    assert_eq!(
-        Query::insert()
-            .into_table(Glyph::Table)
-            .json(json!({
-                "image": "24B0E11951B03B07F8300FD003983F03F0780060",
-                "aspect": 2.1345,
-            }))
-            .to_string(PostgresQueryBuilder),
-        r#"INSERT INTO "glyph" ("aspect", "image") VALUES (2.1345, '24B0E11951B03B07F8300FD003983F03F0780060')"#
-    );
-}
-
 #[test]
 #[allow(clippy::approx_constant)]
 fn insert_2() {
@@ -721,7 +705,7 @@ fn insert_3() {
                 "04108048005887010020060000204E0180400400".into(),
                 3.1415.into(),
             ])
-            .values_panic(vec![Value::Null, 2.1345.into(),])
+            .values_panic(vec![Value::String(None), 2.1345.into(),])
             .to_string(PostgresQueryBuilder),
         r#"INSERT INTO "glyph" ("image", "aspect") VALUES ('04108048005887010020060000204E0180400400', 3.1415), (NULL, 2.1345)"#
     );
@@ -771,22 +755,6 @@ fn update_1() {
     );
 }
 
-#[test]
-#[cfg(feature = "with-json")]
-fn update_2() {
-    assert_eq!(
-        Query::update()
-            .table(Glyph::Table)
-            .json(json!({
-                "aspect": 2.1345,
-                "image": "24B0E11951B03B07F8300FD003983F03F0780060",
-            }))
-            .and_where(Expr::col(Glyph::Id).eq(1))
-            .to_string(PostgresQueryBuilder),
-        r#"UPDATE "glyph" SET "aspect" = 2.1345, "image" = '24B0E11951B03B07F8300FD003983F03F0780060' WHERE "id" = 1"#
-    );
-}
-
 #[test]
 fn update_3() {
     assert_eq!(
